#!/bin/bash

#	Festlegen der Scriptparameter
startdate=$(date +%G-%m-%d__T__%k-%M)
workDir=/root/backup
configDir=/etc/cvbackup

# 	Festlegen der Konfigurationsdateien
folderConfigfile=$configDir/folder.conf
databaseConfig=$configDir/mysql_database.conf
excludes=$configDir/folder_excludes.conf

# 	Sourcen der Minimalkonfiguration
. $configDir/basic.conf

# 	Erstellen eines temporren Logfiles unter /tmp/
logfile=$(mktemp /tmp/backup-XXXXXXXX)

echo "Start of Backup" >> $logfile

#
# 	Lschen eines bestehenden Rotateflags (Falls vorheriges Backup noch nicht rotiert wurde.)
# 	Hier wird dann der vorhergehende Backupstand berschrieben
echo "Remove previous Rotateflag" >> $logfile
$(ssh -i $privateKeyfile -p $remotePort $remoteUser@$remoteServer "rm -f /srv/backup/$HOSTNAME/finished") >> $logfile

#
# 	Prfen ob Datenbankkonfiguration hinterlegt wurde.
if ( test -e $databaseConfig ); then

	# Wenn Konfiguration gefunden wurde, Datenbankbackup durchfhren.
	$workDir/backup_sql.sh >> $logfile

fi


#
# 	Backup fr alle konfigurierten Ordner ($folderConfigfile) durchfhren und Daten auf Zielserver kopieren.
for folder in $(cat $folderConfigfile)
do

	echo "starting backup of $folder" >> $logfile

	# 	Prfen ob $folder auf Zielserver im Backupfolder existiert. Wenn er nicht existiert, wird er vor dem kopieren angelegt.
	$(ssh -i $privateKeyfile -p $remotePort $remoteUser@$remoteServer "mkdir -p /srv/backup/$HOSTNAME/current/$folder") >> $logfile

	# 	Kopieren der Daten (Komprimiert, Checksummenprfung zur Auswahl genderter Dateien, Rekursive Verarbeitung, Zeitstempel erhalten, Berechtigungen erhalten
	#	Usergruppe beibehalten, Owner beibehalten, Hardlinks beachten).
	rsync -zcrtpgoh -e "ssh -i $privateKeyfile -p $remotePort" --delete --delete-excluded --delete-after --numeric-ids --exclude-from=$excludes --progress --stats $folder/ $remoteUser@$remoteServer:/srv/backup/$HOSTNAME/current/$folder >> $logfile

	echo "backup of $folder finished" >> $logfile
done

#
#	Backup in die vorgegebene Verzeichnisstruktur linken. Dadurch wird der bentigte Speicherplatz minimiert, da unvernderte
#	Dateien einen Dateisystemlink in das neue Verzeichnis bekommen. Auf Verzeichnisebene hat man jedoch immer den Zustand eines Vollbackups.
echo "rotate the backup" >> $logfile
$(ssh -i $privateKeyfile -p $remotePort $remoteUser@$remoteServer "touch /srv/backup/$HOSTNAME/finished") >> $logfile


#
#	Speichern des Logfiles.
mv $logfile "$workDir/logs/backup_$startdate"


